embedded_message = {
  "configuration_options_log-ru": "Настройки успешно были проверены и записаны",
  "configuration_options_not_change_log-ru": "Новых настроек не постуало, поэтому класс работает на настройках по умолчанию",

  "storage_fill-ru": "В хранилище из запроса были данные и оно было скопировано",
  "storage_not_fill-ru": "В хранилище из запроса небыло данных",

  # Логи для KeyWord
  "key_word_init_log-ru": "Класс по поиску ключевых слов был проинициолизирован",
  "key_word_log-ru": "Поиск по ключевым словам прошол успешно",
  "key_word_not_found_log-ru": "Поиск по ключевым словам ничего не нашол",
#   "key_word_log_error-ru": "Поиск по ключевым словам не прошoл возникла ошибка",


  "buttons_success_founded-ru": "Все кнопки успешно найдены",




#   "get_events_log-ru": "GET: Запрос на получение 'events'",
#   "get_buttons_log-ru": "GET: Запрос на получение 'buttons'",
#   "get_key_words_log-ru": "GET: Запрос на получение 'key_words'",
#   "get_intents_log-ru": "GET: Запрос на получение 'intents'",
#   "get_storage_log-ru": "GET: Запрос на получение 'storage'",
#   "add_storage_log-ru": "Запрос на добавление в 'storage'",
#   "update_storage_log-ru": "Запрос на обнавление элемента 'storage'",
#   "update_in_add_storage_log-ru": "Запрос на обнавление элемента 'storage' из метада 'add_storage()'",


  "event_success_add-ru": "Event '{}' успешно записан",
  "event_success_call-ru": "Функция event(а) '{}' успешно выполнена",


  "session_end-ru": "Сесия переведена с статус 'False'", 

#   "not_text_log": "Текста в ответе от Алисы нет, поэтому работать с текстом нецелесообразно",

#   "configuration_options_log_error": "Настройки по какой то причине не были записаны",


#   "change_debug": "Чтобы увидеть логи поменяйте настройку 'debug' на true и предайте новые настройк классу PyAlice",

    "first_starting_end-ru": "Первый запуск успешно завершён",


    # english language
    "configuration_options_log-en": "The settings were successfully checked and recorded",

    "first_starting_end-en": "The first launch was successfully completed",
}