EMBEDDED_ERRORS_MESSAGE = {
  "color_logs_error-ru": "метод add_log() принимает либо color либо type",
  
  "key_word_duplicate_error-ru": "Поиск по ключевым словам вернул болле одного ключевого слова, проверьте чтобы ключевые слова не пересикались между собой",





  "events_setting_error-ru": "тип даных 'EVENTS' должен быть bool",
  "debug_setting_error-ru": "тип даных 'DEBUG' должен быть bool",
  "buttons_dialogs_auto_setting_error-ru": "тип даных 'BUTTONS_MESSAGE' должен быть bool",
  "time_zone_setting_error-ru": "'TIME_ZONE' должен выгледеть так 'UTC+3' или '+3'",
  "text_for_key_word_setting_error-ru": "'TEXT_FOR_INTENTS' и 'TEXT_FOR_KEY_WORDS' должен быть равны 'commands' или 'original_utterance'",
  "language_setting_error-ru": "Язык указан невено",
  "starting_dialog_setting_error-ru": "Стартовая фраза не указана",
  "source_text_setting_error-ru": "'SOURCE_TEXT' должен быть равным 'commands' или 'original_utterance'",






  "dialog_not_found_error-ru": "Диалог с ключом '{}' не найден",

  "group_buttons_not_found_error-ru": "Группа кнопок '{}' не найдена",
  "button_not_found_error-ru": "Кнопока '{}' не найдена",

  "item_in_storage_not_found_error-ru": "Запись в хранилище с именем '{}' не найдена",
  "overwrite_storage_error-ru": "'{}' такая запись уже сущетвует в хранилище и её перезапись невозможа, так как параметр 'overwrite' в состоянии True",

#   "get_params_type_error-ru": "Атрибут type в методы get_params должен быть равен либо 'json' либо 'dict'",


    "events_setting_error-en": "the 'EVENTS' data type should be bool",
}